Improve this Doc View Source

Sets the `checked` attribute on the element, if the expression inside `ngChecked` is truthy.

Note that this directive should not be used together with `ngModel`, as this can lead to unexpected behavior.

A special directive is necessary because we cannot use interpolation inside the `checked` attribute. See the interpolation guide for more info.

## Directive Info

- This directive executes at priority level 100.

## Usage

- as attribute:

      <INPUT
        ng-checked="expression">
      ...
      </INPUT>

### Arguments

Param | Type | Details
--- | --- | ---
ngChecked | expression | If the expression is truthy, then the `checked` attribute will be set on the element

## Examples

    <label>Check me to check both: <input type="checkbox" ng-model="master"></label><br/>
    <input id="checkSlave" type="checkbox" ng-checked="master" aria-label="Slave input">

    it('should check both checkBoxes', function() {
      expect(element(by.id('checkSlave')).getAttribute('checked')).toBeFalsy();
      element(by.model('master')).click();
      expect(element(by.id('checkSlave')).getAttribute('checked')).toBeTruthy();
    });